@@ -4,8 +4,8 @@
  * This file is part of ePiX, a C++ library for creating high-quality
  * figures in LaTeX
  *
- * Version 1.0.23
- * Last Change: January 04, 2007
+ * Version 1.1.10
+ * Last Change: August 08, 2007
  */
 
 /* 
@@ -35,33 +35,31 @@
 #ifndef EPIX_CURVES
 #define EPIX_CURVES
 
-#include "globals.h"
+#include <vector>
+
+#include "constants.h"
 
 namespace ePiX {
 
   class P;
   class mesh;
 
-  extern double x_min, y_min, x_max, y_max;
-
   // lines can be "stretched" by double parameter
-  void line(const P& tail, const P& head, const double expand=0); 
-  void line(const P& tail, const P& head, const double expand,
-	    int num_pts);
+  void line(const P& tail, const P& head, double expand=0); 
+  void line(const P& tail, const P& head, double expand,
+	    unsigned int num_pts);
 
   // "Visible" portion of the line through p1, p2
   void Line(const P& tail, const P& head);
 
   // point-slope form
-  void Line(const P&, const double);
+  void Line(const P&, double);
 
   void triangle(const P&, const P&, const P&);
   void quad(const P&, const P&, const P&, const P&);
 
-  void draw_rect(const P&, const P&); // opposite corners
-  void rect(const P&, const P&, bool solid=epix::fill_paths);
-  // filled rectangle; deprecated
-  void swatch(const P&, const P&);
+  void rect(const P&, const P&);
+  void rect(const P&, const P&, bool solid);
 
   // arrows
   void arrow(const P& tail, const P& head, double scale=1);
@@ -70,15 +68,22 @@ namespace ePiX {
   // double-tipped
   void aarrow(const P& tail, const P& head, double scale=1);
 
+  // arbitrary elliptical arc
+  void arrow(const P& center, const P& axis1, const P& axis2,
+	     double t_min, double t_max, double scale=1);
+
   // Algebraic curves (elliptical and circular arcs, splines)
+  void ellipse(const P& center, const P& axis1, const P& axis2); // full turn
+
   void ellipse(const P& center, const P& axis1, const P& axis2,  
-	       const double t_min=0, 
-	       const double t_max=epix::full_turn(),
-	       int num_pts=EPIX_NUM_PTS);
+	       double t_min, double t_max); // angle range
+
+  void ellipse(const P& center, const P& axis1, const P& axis2,  
+	       double t_min, double t_max, unsigned int num_pts);
 
   // for backward compatibility
   void ellipse_arc(const P& center, const P& axis1, const P& axis2,
-		   const double t_min, const double t_max);
+		   double t_min, double t_max);
 
   // old style "center and polyradius"
   void ellipse (const P& center, const P& radius);
@@ -90,25 +95,32 @@ namespace ePiX {
   void ellipse_bottom (const P&, const P&);
 
   // Circular arcs parallel to (x,y)-plane
-  void arc(const P& center, const double r, 
-	   const double start,  const double finish);
+  void arc(const P& center, double r, 
+	   double start,  double finish);
 
-  void arc_arrow (const P& center, const double r, 
-		  const double start, const double finish, 
-		  const double scale=1);
+  void arc_arrow (const P& center, double r, 
+		  double start, double finish, 
+		  double scale=1);
 
 
   // Quadratic and cubic splines/spline arrows
-  void spline(const P& p1, const P& p2, const P& p3, int num_pts=EPIX_NUM_PTS);
+  void spline(const P& p1, const P& p2, const P& p3, unsigned int num_pts);
+  void spline(const P& p1, const P& p2, const P& p3);
+
   void arrow(const P& p1, const P& p2, const P& p3, double scale=1);
 
   void spline (const P& p1, const P& p2, const P& p3, const P& p4,
-	       int num_pts=EPIX_NUM_PTS);
+	       unsigned int num_pts);
+  void spline (const P& p1, const P& p2, const P& p3, const P& p4);
+
   void arrow(const P&, const P&, const P&, const P&, double scale=1);
 
+  // natural spline
+  void spline(const std::vector<P>&, unsigned int num_pts);
+
 
   // A "mesh" is an ordered pair of positive integers, and is used to
-  // specify the "fineness" of a mesh. Grids, like parametric surface
+  // specify the "fineness" of a grid. Grids, like parametric surface
   // meshes, have a "coarse mesh" -- the numbers of grid intervals in
   // each direction, and a "fine mesh" -- the numbers of points used
   // to render the grid lines. Since an ePiX camera does not always
@@ -121,15 +133,15 @@ namespace ePiX {
   void grid(const P& arg1, const P& arg2, mesh coarse, mesh fine);
 
   // coarse = fine = (n1,n2)
-  void grid(const P& arg1, const P& arg2, int n1=1, int n2=1);
-  void grid(int n1=1, int n2=1);
+  void grid(const P& arg1, const P& arg2,
+	    unsigned int n1=1, unsigned int n2=1);
+  void grid(unsigned int n1=1, unsigned int n2=1);
 
   // polar grid of specified radius, mesh (rings and sectors), and resolution
-  void draw_polar_grid(double r, mesh coarse, mesh fine);
   void polar_grid(double r, mesh coarse, mesh fine);
 
   // polar grid with n1 rings and n2 sectors
-  void polar_grid(double r, int n1, int n2);
+  void polar_grid(double r, unsigned int n1, unsigned int n2);
 
 
   // (semi-)logarithmic grids specified by corners and numbers of orders of
