@@ -4,8 +4,8 @@
  * This file is part of ePiX, a preprocessor for creating high-quality 
  * line figures in LaTeX 
  *
- * Version 1.1
- * Last Change: January 01, 2007
+ * Version 1.1.6
+ * Last Change: July 04, 2007
  */
 
 /* 
@@ -37,7 +37,6 @@
 
 #include <list>
 
-#include "globals.h"
 #include "triples.h"
 #include "functions.h"
 
@@ -59,8 +58,6 @@ namespace ePiX {
     int n_3;
   }; // end of class mesh
 
-  typedef mesh Net; // compatibility
-
   // A domain is a gridded coordinate box with specified corners
   // and coarse/fine meshes, used for plotting. The "coarse" step
   // sizes are step1, etc., and the "fine" step sizes are dx1, etc.
@@ -74,17 +71,11 @@ namespace ePiX {
   //
   class domain {
   public:
-    P corner1;
-    P corner2;
-    mesh coarse;
-    mesh fine;
-
-    domain(P arg1=P(1,1,1), P arg2=P(0,0,0), 
-	   mesh c=mesh(1,1,1), mesh f=mesh(1,1,1));
+    domain(const P& arg1, const P& arg2, const mesh& c, const mesh& f);
+    domain(const P& arg1, const P& arg2, const mesh& c);
 
     // 1-dim'l domain
-    domain(double t_min, double t_max, int num_pts)
-      : corner1(t_min), corner2(t_max), coarse(num_pts), fine(num_pts) { }
+    domain(double t_min, double t_max, int num_pts);
 
     int dim() const; // dimension
 
@@ -111,6 +102,32 @@ namespace ePiX {
     std::list<domain> slices1(const unsigned int n=0) const;
     std::list<domain> slices2(const unsigned int n=0) const;
     std::list<domain> slices3(const unsigned int n=0) const;
+
+    // state  functions for internal use
+    P corner1() const;
+    P corner2() const;
+
+    double corner1_x1() const;
+    double corner1_x2() const;
+    double corner1_x3() const;
+
+    double corner2_x1() const;
+    double corner2_x2() const;
+    double corner2_x3() const;
+
+    int coarse_n1() const;
+    int coarse_n2() const;
+    int coarse_n3() const;
+
+    int fine_n1() const;
+    int fine_n2() const;
+    int fine_n3() const;
+
+  private:
+    P m_corner1;
+    P m_corner2;
+    mesh m_coarse;
+    mesh m_fine;
   }; // end of class domain
 
   class domain_list {
