@@ -4,12 +4,12 @@
  * This file is part of ePiX, a preprocessor for creating high-quality 
  * line figures in LaTeX 
  *
- * Version 1.0.23
- * Last Change: April 5, 2007
+ * Version 1.2.3
+ * Last Change: March 09, 2008
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -35,8 +35,8 @@
 #ifndef EPIX_ERRORS
 #define EPIX_ERRORS
 
-#include <cstdlib>
 #include <iostream>
+#include <cstdlib>
 #include <string>
 
 namespace ePiX {
@@ -51,23 +51,6 @@ namespace ePiX {
     std::cerr << "ePiX ERROR: " << msg << std::endl;
     exit(1);
   } 
-
-  // Shape error types
-  enum constructor_error_type {MALFORMED, MULTIPLICITY, COLLINEAR_PTS};
-  enum join_error_type {TANGENT, PARALLEL, COINCIDENT, NON_COPLANAR,
-			SEPARATED, CONCENTRIC};
-
-  // and handlers
-  struct constructor_error {
-    constructor_error_type type;
-    constructor_error(constructor_error_type x)
-    : type(x) { }
-  };
-
-  struct join_error {
-    join_error_type type;
-    join_error(join_error_type x) { type = x; }
-  };
 } // end of namespace
 
 #endif /* EPIX_ERRORS */
