@@ -1,15 +1,15 @@
 /* 
  * pairs.h -- ePiX pair:: class and mathematical operators
  *
- * This file is part of ePiX, a preprocessor for creating high-quality 
- * line figures in LaTeX 
+ * This file is part of ePiX, a C++ library for creating high-quality 
+ * figures in LaTeX 
  *
- * Version 1.0.7
- * Last Change: May 17, 2006
+ * Version 1.1.10
+ * Last Change: August 04, 2007
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -35,41 +35,41 @@
 #ifndef EPIX_PAIRS
 #define EPIX_PAIRS
 
-#include "functions.h"
-#include "triples.h"
-
 namespace ePiX {
 
-  class pair 
-    {
-    public:
-      pair(const double arg1=0, const double arg2=0) : X1(arg1), X2(arg2) { }
-      pair(const P& arg); // take first two coordinates
+  class P;
 
-      double x1() const { return X1; }
-      double x2() const { return X2; }
+  class pair {
+  public:
+    pair(double arg1=0, double arg2=0)
+      : m_x1(arg1), m_x2(arg2) { }
 
-      // unary increment operators
-      pair& operator += (const pair& arg);
-      pair& operator -= (const pair& arg);
-      pair& operator *= (const double c);
+    pair(const P& arg); // take first two coordinates
 
-      // complex multiplication and division
-      pair& operator *= (const pair& arg);
-      pair& operator /= (const pair& arg);
-      bool operator== (const pair& u) const;
-      bool operator!= (const pair& u) const;
+    double x1() const { return m_x1; }
+    double x2() const { return m_x2; }
 
-    private:
-      double X1;
-      double X2;
+    // unary increment operators
+    pair& operator += (const pair& arg);
+    pair& operator -= (const pair& arg);
+    pair& operator *= (double c);
 
-    }; // end of class pair
+    // complex multiplication and division
+    pair& operator *= (const pair& arg);
+    pair& operator /= (const pair& arg);
+    bool operator== (const pair& u) const;
+    bool operator!= (const pair& u) const;
+
+  private:
+    double m_x1;
+    double m_x2;
+
+  }; // end of class pair
   
   pair operator- (pair u);
   pair operator+ (pair u, const pair& v);
   pair operator- (pair u, const pair& v);
-  pair operator* (const double c, pair u);
+  pair operator* (double c, pair u);
 
   // complex arithmetic
   pair J(pair p);
