@@ -1,10 +1,13 @@
 /*
  * plots.h -- parametrized plotting algorithms
  *
+ * This file is part of ePiX, a C++ library for creating high-quality 
+ * figures in LaTeX 
+ *
  * Andrew D. Hwang   <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  *
- * Version 1.1
- * Last Change: January 01, 2007
+ * Version 1.0.23
+ * Last Change: January 13, 2007
  */
 
 /* 
@@ -33,6 +36,8 @@
 #ifndef EPIX_PLOTS
 #define EPIX_PLOTS
 
+#include "enums.h"
+
 namespace ePiX {
 
   class domain;
@@ -43,23 +48,23 @@ namespace ePiX {
 
   //// paths ////
   // f:R -> R^3
-  void plot (P f(double), double t_min, double t_max, int num_pts);
+  void plot (P f(double), double t_min, double t_max, unsigned int n);
 
   // f:R -> R x R x R
   void plot (double f1(double), double f2(double), double f3(double),
-	     double t_min, double t_max, int num_pts);
+	     double t_min, double t_max, unsigned int n);
 
   // f:R -> R
-  void plot (double f(double), double t_min, double t_max, int num_pts);
-  void plot (const Deriv&, double t_min, double t_max, int num_pts);
-  void plot (const Integral&, double t_min, double t_max, int num_pts);
+  void plot (double f(double), double t_min, double t_max, unsigned int n);
+  void plot (const Deriv&, double t_min, double t_max, unsigned int n);
+  void plot (const Integral&, double t_min, double t_max, unsigned int n);
 
   // f: R -> R x R
   void plot (double f1(double), double f2(double), 
-	     double t_min, double t_max, int num_pts);
+	     double t_min, double t_max, unsigned int n);
+
+  void polarplot (double f(double), double t_min, double t_max, unsigned int);
 
-  void polarplot (double f(double), double t_min, double t_max, int num_pts);
-  
   //// surfaces ////
   // f:R^2 -> R x R x R
   void plot(double f1(double u1, double u2),
@@ -86,22 +91,24 @@ namespace ePiX {
 
 
   // Derivatives and integrals
-  void plot_deriv(double f(double), double a, double b, int num_pts);
+  void plot_deriv(double f(double), double a, double b, unsigned int n);
 
-  void plot_int(double f(double), double a, double b, int num_pts);
+  void plot_int(double f(double), double a, double b, unsigned int n);
 
-  void plot_int(double f(double), double x0, double a, double b, int num_pts);
+  void plot_int(double f(double), double x0, double a, double b, unsigned int);
 
   void tan_line(double f1(double), double f2(double), double t0);
   void tan_line(double f(double), double t0);
   void tan_line(P f(double), double t0);
 
-  void envelope(double f1(double), double f2(double), double, double, int);
-  void envelope(double f(double), double, double, int);
-  void envelope(P f(double), double, double, int);
+  void envelope(double f1(double), double f2(double),
+		double, double, unsigned int);
+  void envelope(double f(double), double, double, unsigned int);
+  void envelope(P f(double), double, double, unsigned int);
 
-  void tan_field(double f1(double), double f2(double), double, double, double);
-  void tan_field(P f(double), double, double, double);
+  void tan_field(double f1(double), double f2(double), double, double,
+		 unsigned int);
+  void tan_field(P f(double), double, double, unsigned int);
 
 
   // Slope, dart, and vector fields
@@ -110,86 +117,89 @@ namespace ePiX {
   // are drawn at true length, and "scale" affects the arrowhead size.
 
   // planar fields
-  void  slope_field(P F(double, double), const P& p, const P& q, int, int,
-		    const double scale=1.0);
-  void   dart_field(P F(double, double), const P& p, const P& q, int, int,
-		    const double scale=1.0);
-  void vector_field(P F(double, double), const P& p, const P& q, int, int,
-		    const double scale=1.0);
+  void  slope_field(P F(double, double), const P& p, const P& q,
+		    unsigned int, unsigned int, double scale=1.0);
+  void   dart_field(P F(double, double), const P& p, const P& q,
+		    unsigned int, unsigned int, double scale=1.0);
+  void vector_field(P F(double, double), const P& p, const P& q,
+		    unsigned int, unsigned int, double scale=1.0);
 
   void  slope_field(P F(double, double), const domain& R,
-		    const double scale=1.0);
+		    double scale=1.0);
   void   dart_field(P F(double, double), const domain& R,
-		    const double scale=1.0);
+		    double scale=1.0);
   void vector_field(P F(double, double), const domain& R,
-		    const double scale=1.0);
+		    double scale=1.0);
 
   // spatial fields
-  void  slope_field(P F(double, double, double), const P&, const P&, int, int,
-		    const double scale=1.0);
-  void   dart_field(P F(double, double, double), const P&, const P&, int, int,
-		    const double scale=1.0);
-  void vector_field(P F(double, double, double), const P&, const P&, int, int,
-		    const double scale=1.0);
+  void  slope_field(P F(double, double, double), const P&, const P&,
+		    unsigned int, unsigned int, double scale=1.0);
+  void   dart_field(P F(double, double, double), const P&, const P&,
+		    unsigned int, unsigned int, double scale=1.0);
+  void vector_field(P F(double, double, double), const P&, const P&,
+		    unsigned int, unsigned int, double scale=1.0);
 
   // spatial fields over a (3-D) domain
   void  slope_field(P F(double, double, double), const domain&,
-		    const double scale=1.0);
+		    double scale=1.0);
   void   dart_field(P F(double, double, double), const domain&,
-		    const double scale=1.0);
+		    double scale=1.0);
   void vector_field(P F(double, double, double), const domain&,
-		    const double scale=1.0);
+		    double scale=1.0);
 
 
   // Solutions of ODE systems
 
   // start at time 0
   void ode_plot (P F(double, double),
-		 const P& start, double t_max, int num_pts);
+		 const P& start, double t_max, unsigned int);
 
   void ode_plot (P F(double, double, double),
-		 const P& start, double t_max, int num_pts);
+		 const P& start, double t_max, unsigned int);
 
   // arbitrary start time
   void ode_plot (P F(double, double),
-		 const P& start, double t_min, double t_max, int num_pts);
+		 const P& start, double t_min, double t_max, unsigned int);
 
   void ode_plot (P F(double, double, double),
-		 const P& start, double t_min, double t_max, int num_pts);
+		 const P& start, double t_min, double t_max, unsigned int);
 
   // flow x0 under field for specified time
-  P flow (P F(double, double), const P& start, double t_max, int num_pts = 0);
+  P flow (P F(double, double), const P& start, double t_max, unsigned int n=0);
   P flow (P F(double, double, double),
-	  const P& start, double t_max, int num_pts = 0);
+	  const P& start, double t_max, unsigned int n = 0);
 
-  void riemann_sum(double f(double), const double a, const double b,
+  void riemann_sum(double f(double), double a, double b,
 		   unsigned int n, epix_integral_type TYPE);
 
 
   // Jay Belanger's shaded plot functions -- December 1, 2002
-  void shadeplot(double f1(double), double f2(double), double, double, int);
-  void shadeplot(double f(double), double t_min, double t_max, int num_pts);
+  void shadeplot(double f1(double), double f2(double), double, double,
+		 unsigned int);
+  void shadeplot(double f(double), double t_min, double t_max, unsigned int);
 
   void blackplot(double f1(double), double f2(double), 
-		 double t_min, double t_max, int num_pts);
+		 double t_min, double t_max, unsigned int);
 
-  void blackplot(double f(double), double t_min, double t_max, int num_pts);
+  void blackplot(double f(double), double t_min, double t_max, unsigned int);
 
   void whiteplot(double f1(double), double f2(double), 
-		 double t_min, double t_max, int num_pts);
+		 double t_min, double t_max, unsigned int);
 
-  void whiteplot(double f(double), double t_min, double t_max, int num_pts);
+  void whiteplot(double f(double), double t_min, double t_max, unsigned int);
 
 
   // wiremesh surface plotting
   void plot(P Phi(double, double),
 	    const P&, const P&, const mesh& N, const mesh& num_pts);
 
+  /*
   void clipplot(P Phi(double, double),
 	    const P&, const P&, const mesh& N, const mesh& num_pts);
 
   void cropplot(P Phi(double, double),
 		const P&, const P&, const mesh& N, const mesh& num_pts);
+  */
 
 } // end of namespace
 
