@@ -4,12 +4,12 @@
  * This file is part of ePiX, a C++ library for creating high-quality 
  * figures in LaTeX 
  *
- * Version 1.1.9
- * Last Change: July 30, 2007
+ * Version 1.2.5
+ * Last Change: May 04, 2008
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -93,18 +93,18 @@ namespace ePiX {
     return *this;
   }
 
-  P Segment::midpoint() const
+  P Segment::midpoint(double t) const
   {
-    return 0.5*(m_endpt1 + m_endpt2);
+    return m_endpt1 + t*(m_endpt2 - m_endpt1);
   }
 
-  void Segment::draw() const
+  void Segment::draw(double stretch) const
   {
     if (m_malformed)
       return;
 
     // else
-    path temp(m_endpt1, m_endpt2);
+    path temp(m_endpt1, m_endpt2, stretch);
 
     temp.draw();
   }
