@@ -4,12 +4,12 @@
  * This file is part of ePiX, a C++ library for creating high-quality 
  * figures in LaTeX 
  *
- * Version 1.1.9
- * Last Change: July 30, 2007
+ * Version 1.2.5
+ * Last Change: May 04, 2008
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -39,7 +39,7 @@
  *    - end1(), end2() (no guaranteed order)
  *    - Translation operators shift(P), move_to(P)
  *    - Stretch about midpoint: scale(double)
- *    - draw() (ePiX line)
+ *    - draw(double) (ePiX line)
  *    - midpoint();
  */
 
@@ -69,9 +69,9 @@ namespace ePiX {
 
     Segment& scale(double);
 
-    P midpoint() const;
+    P midpoint(double t=0.5) const;
 
-    void draw() const;
+    void draw(double stretch=0) const;
 
   private:
     P m_endpt1;
