@@ -1,15 +1,15 @@
 /* 
  *  triples.h -- ePiX::P class
  *
- * This file is part of ePiX, a preprocessor for creating high-quality 
- * line figures in LaTeX 
+ * This file is part of ePiX, a C++ library for creating high-quality 
+ * figures in LaTeX 
  *
- * Version 1.0.15
- * Last Change: Obcober 09, 2006
+ * Version 1.1.10
+ * Last Change: August 04, 2007
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -50,8 +50,6 @@
 #ifndef EPIX_TRIPLES
 #define EPIX_TRIPLES
 
-#include "globals.h"
-
 namespace ePiX {
 
   class P {
@@ -62,10 +60,12 @@ namespace ePiX {
     double x2() const;
     double x3() const;
 
+    bool is_valid() const; // coords not inf or nan
+
     // increment operators
     P& operator += (const P&);
     P& operator -= (const P&);
-    P& operator *= (const double); // scalar multipication
+    P& operator *= (double); // scalar multipication
 
     // cross product
     P& operator *= (const P&);
@@ -77,10 +77,9 @@ namespace ePiX {
     P& operator %= (const P&);
 
   private:
-    double m_X1, m_X2, m_X3;
+    double m_x1, m_x2, m_x3;
   }; // end of class P
 
-  typedef P triple; // compatibility alias
 
   // standard basis in global namespace
   const P E_1(1,0,0);
@@ -88,26 +87,24 @@ namespace ePiX {
   const P E_3(0,0,1);
 
   // vector space operations
-  P operator- (const P& u);  // unary negation
-  P operator+ (const P& u, const P& v);
-  P operator- (const P& u, const P& v);
+  P operator- (P u);  // unary negation
+  P operator+ (P u, const P& v);
+  P operator- (P u, const P& v);
   // scalar multiplication
-  P operator* (const double c, const P& v);
-
-  P midpoint(const P& u, const P& v, const double t=0.5);
+  P operator* (double c, P v);
 
   // cross product
-  P operator* (const P&, const P&);
-  P J(const P&); // quarter turn about E_3-axis
+  P operator* (P, const P&);
+  P J(P); // quarter turn about E_3-axis
 
   // dot product
   double operator | (const P&, const P&);
   double norm(const P&);
 
   // componentwise product (a,b,c)&(x,y,z)=(ax,by,cz)
-  P operator& (const P&, const P&);
+  P operator& (P, const P&);
   // orthogonalization
-  P operator% (const P&, const P&);
+  P operator% (P, const P&);
 
   // (in)equality
   bool operator == (const P&, const P&);
